Filesystem-based key-value stores
*********************************

A straightforward implementation is a filesystem-based implementation found in
:class:`minimalkv.fs.FilesystemStore` class, as well as a slightly altered
version suitable for web applications, :class:`minimalkv.fs.WebFilesystemStore`.

.. automodule:: minimalkv.fs
   :members:
